==> zio-aws-mediapackagev2_2.12-7.21.15.8-sources.jar: zio/aws/mediapackagev2/model/package.scala <==
package zio.aws.mediapackagev2
import zio.aws.mediapackagev2.model.primitives.{TagValue, TagKey}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.mediapackagev2.model.primitives.FilterConfigurationManifestFilterString.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object CreateHlsManifestConfigurationManifestWindowSecondsInteger
        extends Subtype[Int]
    type CreateHlsManifestConfigurationManifestWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateHlsManifestConfigurationManifestWindowSecondsInteger.Type
    object CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
        extends Subtype[Int]
    type CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger.Type
    object CreateLowLatencyHlsManifestConfigurationManifestWindowSecondsInteger
        extends Subtype[Int]
    type CreateLowLatencyHlsManifestConfigurationManifestWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateLowLatencyHlsManifestConfigurationManifestWindowSecondsInteger.Type
    object CreateLowLatencyHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
        extends Subtype[Int]
    type CreateLowLatencyHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateLowLatencyHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger.Type
    object CreateOriginEndpointRequestStartoverWindowSecondsInteger
        extends Subtype[Int]
    type CreateOriginEndpointRequestStartoverWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateOriginEndpointRequestStartoverWindowSecondsInteger.Type
    object EncryptionConstantInitializationVectorString extends Subtype[String]
    type EncryptionConstantInitializationVectorString =
      zio.aws.mediapackagev2.model.primitives.EncryptionConstantInitializationVectorString.Type
    object EncryptionKeyRotationIntervalSecondsInteger extends Subtype[Int]
    type EncryptionKeyRotationIntervalSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.EncryptionKeyRotationIntervalSecondsInteger.Type
    object FilterConfigurationManifestFilterString extends Subtype[String]
    type FilterConfigurationManifestFilterString =
      zio.aws.mediapackagev2.model.primitives.FilterConfigurationManifestFilterString.Type
    object FilterConfigurationTimeDelaySecondsInteger extends Subtype[Int]
    type FilterConfigurationTimeDelaySecondsInteger =
      zio.aws.mediapackagev2.model.primitives.FilterConfigurationTimeDelaySecondsInteger.Type
    object IdempotencyToken extends Subtype[String]
    type IdempotencyToken =
      zio.aws.mediapackagev2.model.primitives.IdempotencyToken.Type
    type Integer = Int
    object ListResourceMaxResults extends Subtype[Int]
    type ListResourceMaxResults =
      zio.aws.mediapackagev2.model.primitives.ListResourceMaxResults.Type
    object ManifestName extends Subtype[String]
    type ManifestName =
      zio.aws.mediapackagev2.model.primitives.ManifestName.Type
    object PolicyText extends Subtype[String]
    type PolicyText = zio.aws.mediapackagev2.model.primitives.PolicyText.Type
    object ResourceDescription extends Subtype[String]
    type ResourceDescription =
      zio.aws.mediapackagev2.model.primitives.ResourceDescription.Type
    object ResourceName extends Subtype[String]
    type ResourceName =
      zio.aws.mediapackagev2.model.primitives.ResourceName.Type
    object SegmentSegmentDurationSecondsInteger extends Subtype[Int]
    type SegmentSegmentDurationSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.SegmentSegmentDurationSecondsInteger.Type
    object SegmentSegmentNameString extends Subtype[String]
    type SegmentSegmentNameString =
      zio.aws.mediapackagev2.model.primitives.SegmentSegmentNameString.Type
    object SpekeKeyProviderResourceIdString extends Subtype[String]
    type SpekeKeyProviderResourceIdString =
      zio.aws.mediapackagev2.model.primitives.SpekeKeyProviderResourceIdString.Type
    object SpekeKeyProviderRoleArnString extends Subtype[String]
    type SpekeKeyProviderRoleArnString =
      zio.aws.mediapackagev2.model.primitives.SpekeKeyProviderRoleArnString.Type
    object SpekeKeyProviderUrlString extends Subtype[String]
    type SpekeKeyProviderUrlString =
      zio.aws.mediapackagev2.model.primitives.SpekeKeyProviderUrlString.Type
    object TagArn extends Subtype[String]
    type TagArn = zio.aws.mediapackagev2.model.primitives.TagArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.mediapackagev2.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.mediapackagev2.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.mediapackagev2.model.primitives.Timestamp.Type
    object UpdateOriginEndpointRequestStartoverWindowSecondsInteger
        extends Subtype[Int]
    type UpdateOriginEndpointRequestStartoverWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.UpdateOriginEndpointRequestStartoverWindowSecondsInteger.Type
  }
  type ChannelGroupsList =
    List[zio.aws.mediapackagev2.model.ChannelGroupListConfiguration]
  type ChannelList = List[zio.aws.mediapackagev2.model.ChannelListConfiguration]
  type CreateHlsManifests =
    List[zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration]
  type CreateLowLatencyHlsManifests =
    List[zio.aws.mediapackagev2.model.CreateLowLatencyHlsManifestConfiguration]
  type GetHlsManifests =
    List[zio.aws.mediapackagev2.model.GetHlsManifestConfiguration]
  type GetLowLatencyHlsManifests =
    List[zio.aws.mediapackagev2.model.GetLowLatencyHlsManifestConfiguration]
  type IngestEndpointList = List[zio.aws.mediapackagev2.model.IngestEndpoint]
  type ListHlsManifests =
    List[zio.aws.mediapackagev2.model.ListHlsManifestConfiguration]
  type ListLowLatencyHlsManifests =
    List[zio.aws.mediapackagev2.model.ListLowLatencyHlsManifestConfiguration]
  type OriginEndpointsList =
    List[zio.aws.mediapackagev2.model.OriginEndpointListConfiguration]
  type ScteFilterList = List[zio.aws.mediapackagev2.model.ScteFilter]
  type SpekeKeyProviderDrmSystemsList =
    List[zio.aws.mediapackagev2.model.DrmSystem]
  type TagKeyList = List[TagKey]
  type TagMap = Map[TagKey, TagValue]
}

==> zio-aws-mediapackagev2_3-7.21.15.7-sources.jar: zio/aws/mediapackagev2/model/package.scala <==
package zio.aws.mediapackagev2
import zio.aws.mediapackagev2.model.primitives.{TagValue, TagKey}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.mediapackagev2.model.primitives.FilterConfigurationManifestFilterString.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object CreateHlsManifestConfigurationManifestWindowSecondsInteger
        extends Subtype[Int]
    type CreateHlsManifestConfigurationManifestWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateHlsManifestConfigurationManifestWindowSecondsInteger.Type
    object CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
        extends Subtype[Int]
    type CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger.Type
    object CreateLowLatencyHlsManifestConfigurationManifestWindowSecondsInteger
        extends Subtype[Int]
    type CreateLowLatencyHlsManifestConfigurationManifestWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateLowLatencyHlsManifestConfigurationManifestWindowSecondsInteger.Type
    object CreateLowLatencyHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger
        extends Subtype[Int]
    type CreateLowLatencyHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateLowLatencyHlsManifestConfigurationProgramDateTimeIntervalSecondsInteger.Type
    object CreateOriginEndpointRequestStartoverWindowSecondsInteger
        extends Subtype[Int]
    type CreateOriginEndpointRequestStartoverWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.CreateOriginEndpointRequestStartoverWindowSecondsInteger.Type
    object EncryptionConstantInitializationVectorString extends Subtype[String]
    type EncryptionConstantInitializationVectorString =
      zio.aws.mediapackagev2.model.primitives.EncryptionConstantInitializationVectorString.Type
    object EncryptionKeyRotationIntervalSecondsInteger extends Subtype[Int]
    type EncryptionKeyRotationIntervalSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.EncryptionKeyRotationIntervalSecondsInteger.Type
    object FilterConfigurationManifestFilterString extends Subtype[String]
    type FilterConfigurationManifestFilterString =
      zio.aws.mediapackagev2.model.primitives.FilterConfigurationManifestFilterString.Type
    object FilterConfigurationTimeDelaySecondsInteger extends Subtype[Int]
    type FilterConfigurationTimeDelaySecondsInteger =
      zio.aws.mediapackagev2.model.primitives.FilterConfigurationTimeDelaySecondsInteger.Type
    object IdempotencyToken extends Subtype[String]
    type IdempotencyToken =
      zio.aws.mediapackagev2.model.primitives.IdempotencyToken.Type
    type Integer = Int
    object ListResourceMaxResults extends Subtype[Int]
    type ListResourceMaxResults =
      zio.aws.mediapackagev2.model.primitives.ListResourceMaxResults.Type
    object ManifestName extends Subtype[String]
    type ManifestName =
      zio.aws.mediapackagev2.model.primitives.ManifestName.Type
    object PolicyText extends Subtype[String]
    type PolicyText = zio.aws.mediapackagev2.model.primitives.PolicyText.Type
    object ResourceDescription extends Subtype[String]
    type ResourceDescription =
      zio.aws.mediapackagev2.model.primitives.ResourceDescription.Type
    object ResourceName extends Subtype[String]
    type ResourceName =
      zio.aws.mediapackagev2.model.primitives.ResourceName.Type
    object SegmentSegmentDurationSecondsInteger extends Subtype[Int]
    type SegmentSegmentDurationSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.SegmentSegmentDurationSecondsInteger.Type
    object SegmentSegmentNameString extends Subtype[String]
    type SegmentSegmentNameString =
      zio.aws.mediapackagev2.model.primitives.SegmentSegmentNameString.Type
    object SpekeKeyProviderResourceIdString extends Subtype[String]
    type SpekeKeyProviderResourceIdString =
      zio.aws.mediapackagev2.model.primitives.SpekeKeyProviderResourceIdString.Type
    object SpekeKeyProviderRoleArnString extends Subtype[String]
    type SpekeKeyProviderRoleArnString =
      zio.aws.mediapackagev2.model.primitives.SpekeKeyProviderRoleArnString.Type
    object SpekeKeyProviderUrlString extends Subtype[String]
    type SpekeKeyProviderUrlString =
      zio.aws.mediapackagev2.model.primitives.SpekeKeyProviderUrlString.Type
    object TagArn extends Subtype[String]
    type TagArn = zio.aws.mediapackagev2.model.primitives.TagArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.mediapackagev2.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.mediapackagev2.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.mediapackagev2.model.primitives.Timestamp.Type
    object UpdateOriginEndpointRequestStartoverWindowSecondsInteger
        extends Subtype[Int]
    type UpdateOriginEndpointRequestStartoverWindowSecondsInteger =
      zio.aws.mediapackagev2.model.primitives.UpdateOriginEndpointRequestStartoverWindowSecondsInteger.Type
  }
  type ChannelGroupsList =
    List[zio.aws.mediapackagev2.model.ChannelGroupListConfiguration]
  type ChannelList = List[zio.aws.mediapackagev2.model.ChannelListConfiguration]
  type CreateHlsManifests =
    List[zio.aws.mediapackagev2.model.CreateHlsManifestConfiguration]
  type CreateLowLatencyHlsManifests =
    List[zio.aws.mediapackagev2.model.CreateLowLatencyHlsManifestConfiguration]
  type GetHlsManifests =
    List[zio.aws.mediapackagev2.model.GetHlsManifestConfiguration]
  type GetLowLatencyHlsManifests =
    List[zio.aws.mediapackagev2.model.GetLowLatencyHlsManifestConfiguration]
  type IngestEndpointList = List[zio.aws.mediapackagev2.model.IngestEndpoint]
  type ListHlsManifests =
    List[zio.aws.mediapackagev2.model.ListHlsManifestConfiguration]
  type ListLowLatencyHlsManifests =
    List[zio.aws.mediapackagev2.model.ListLowLatencyHlsManifestConfiguration]
  type OriginEndpointsList =
    List[zio.aws.mediapackagev2.model.OriginEndpointListConfiguration]
  type ScteFilterList = List[zio.aws.mediapackagev2.model.ScteFilter]
  type SpekeKeyProviderDrmSystemsList =
    List[zio.aws.mediapackagev2.model.DrmSystem]
  type TagKeyList = List[TagKey]
  type TagMap = Map[TagKey, TagValue]
}
